<?php

/**
 * Admin facing class
 *
 * @author Luciana Bruscino
 * @license GPL
 */

class AdminFacing
{
	/**
	 * This function initializes js necessary to be used in the Admin  page
	 *
	 * @return null
	 */
	function initializeScript() {
		wp_register_script( 'MyDomainListScriptColor', WP_PLUGIN_URL . '/my-domain-list/js/jscolor.js' );
		wp_enqueue_script( 'MyDomainListScriptColor' );
	}

	/**
	 * This function add a sub-level menu called My Domain List under the Settings top-level menu in wp-admin
	 *
	 * @return null
	 */
	public function addAdminPage() {
		add_options_page('Domain List Options', 'My Domain List','manage_options', 'my-domain-list-options-page',  array("AdminFacing", "displayAdminPage"));
	}



	/**
	 * This function displays and processes the Admin page in two sessions: 'Setup' and 'Manage'
	 *
	 * @return null
	 */
	public function displayAdminPage(){

		if (!current_user_can('manage_options'))  {
			wp_die( __('You do not have sufficient permissions to access this page.') );
		}

		global $wpdb;
		$my_domain_list_table_name = $wpdb->prefix . "mydomainlist";
		$my_domain_list_table_offer_name = $wpdb->prefix . "mydomainlist_offer";

		if(isset($_POST['my_domain_list_delete_all_submit'])){
			$query = $wpdb->prepare('DELETE FROM '.$my_domain_list_table_name);
			$wpdb->query($query);

			$queryOffer = $wpdb->prepare('DELETE FROM '. $my_domain_list_table_offer_name);
			$wpdb->query($queryOffer);
		}

		if( isset($_POST['my_domain_list_save_submit'] ) )
		{
			// Read their posted value & Save the posted value in the database
			$settingsData['themeBackgroundColor']= $_POST[ 'my_domain_list_bkg_theme_color' ];
			$settingsData['themeColor']= $_POST[ 'my_domain_list_theme_color' ];
			$settingsData['themePages']= $_POST[ 'my_domain_list_page_numbers' ];
			$settingsData['themePaginationType'] = $_POST['my_domain_list_pagination_type'];
			$settingsData['themeTableFilter']= $_POST[ 'my_domain_list_filter' ];
			update_option( 'my_domain_list_settings',$settingsData );
			$myDomainListUpdateReturned = AdminFacing::updateDomainInfo(preg_split("/[\r\n,]+/", trim($_POST[ 'my_domain_name' ]), -1,PREG_SPLIT_NO_EMPTY));
			?>
<div class="updated">
	<p>
		<strong><?php _e('My Domain List settings have been saved.') ?> </strong>
	</p>
	<?php
	if( count($myDomainListUpdateReturned)>0){
		?>
	<p>
		<strong><?php _e('however, some domains were not updated.'). print_r($myDomainListUpdateReturned)?>
		</strong>
	</p>
	<?php
	}
	?>
</div>
	<?php
		}
			
		if( isset($_POST['my_domain_list_refresh_submit' ]) ){
			$forSaleArray=$_POST['myDomainListForSale'];
			$salePriceArray=$_POST['myDomainListPrice'];
			$updateArray=$_POST['myDomainListUpdate'];
			$removeArray=$_POST['myDomainListRemove'];


			$query = $wpdb->prepare('UPDATE '.$my_domain_list_table_name.' SET forsale="N"');
			$wpdb->query($query);
			if(!is_null($forSaleArray)){
				while (list ($key, $val) = each ($forSaleArray)) {
	    $query = $wpdb->prepare('UPDATE '.$my_domain_list_table_name.' SET forsale="Y" WHERE name =%s', $key);
	    $wpdb->query($query);
				}
			}

			if(!is_null($salePriceArray)){
				while (list ($key, $val) = each ($salePriceArray)) {
					if(is_numeric($val)){
						$query = $wpdb->prepare('UPDATE '.$my_domain_list_table_name.' SET price=%d WHERE name =%s', $val, $key);
						$wpdb->query($query);
					}
				}
			}

			if(!is_null($removeArray)){
				while (list ($key, $val) = each ($removeArray)) {
					$query = $wpdb->prepare('DELETE FROM '.$my_domain_list_table_name.' WHERE name in (%s)', $key);
					$wpdb->query($query);

					$queryOffer = $wpdb->prepare('DELETE FROM '. $my_domain_list_table_offer_name . ' WHERE name in (%s)', $key);
					$wpdb->query($queryOffer);
						
				}
			}

			if(!is_null($updateArray)){
				$myDomainListUpdateReturned = AdminFacing::updateDomainInfo($updateArray);
			}
			?>
<div class="updated">
	<p>
		<strong><?php echo _e('My Domain List have been updated.') ?> </strong>
	</p>
</div>
			<?php
				
		}//end if
			
		$settingsData = get_option('my_domain_list_settings');
		$opt_val_page_numbers = (!is_null($settingsData['themePages']))? $settingsData['themePages']: 0;
		$opt_val_theme_color = (!is_null($settingsData['themeColor']))? $settingsData['themeColor']: 'fff';
		$opt_val_theme_bkg_color = (!is_null($settingsData['themeBackgroundColor']))? $settingsData['themeBackgroundColor']: '000';

		$opt_val_filter = (!is_null($settingsData['themeTableFilter']))? $settingsData['themeTableFilter']: 'None';
		$opt_val_pagination_type = (!is_null($settingsData['themePaginationType']))? $settingsData['themePaginationType']: '123';


		AdminFacing::displayAdminSetupSection($opt_val_page_numbers, $opt_val_theme_color, $opt_val_theme_bkg_color, $opt_val_filter, $opt_val_pagination_type);
		AdminFacing::displayAdminManageSection();
	}


	/**
	 * This function displays 'Manage My Domain List' form in the Admin page
	 *
	 * @return null
	 */
	public function displayAdminManageSection(){
	 ?>
<span class="myDomainListAdminHeader"><h3>Manage My Domain List</h3> </span>
<form class="wrap" name="mydomainUpdateform" method="post" action="">
	<input id="domainlistrefresh" type="submit"
		name="my_domain_list_refresh_submit" value="Refresh & Update Data" />
	<input id="domainlistrefresh" type="submit"
		name="my_domain_list_delete_all_submit" value="Remove All Sites" /><br>
		<?php echo AdminFacing::adminAjaxHandler(); ?>
</form>

		<?php
	}

	/**
	 * This function displays 'Setup My Domain List' form in the Admin page
	 *
	 * @return null
	 */
	public function displayAdminSetupSection($themePages, $themeColor, $themeBackgroundColor, $themeFilter, $themePaginationType){
		$pageNumberArray = array(0,5,10,20,50,100);
		$filterArray = array('None','Extension','Registrar','Owner');
		?>
<div class="wrap">
	<div id="icon-tools" class="icon32"></div>
	<h2>
	<?php  echo _e( 'My DomainList Settings')  ?>
	</h2>
	<span class="myDomainListAdminHeader"><h3>
	<?php  echo _e( 'Setup My Domain List') ?>
		</h3> </span>
	<form class="wrap" name="mydomainform" method="post" action="">
		<table name="my_domain_list_table_settings" class="options">
			<tr class="myDomainTableRow">
				<td class="myDomainTableLabel"><?php  echo _e("Enter your domain list:")?>
				</td>
				<td class="myDomainTableInput"><textarea type="text"
						name="my_domain_name" size="20" cols="40" rows="6"></textarea> <br>
					<span class="myDomainListLabelExtraSmall"><?php  echo _e('(enter host name separated by comma or new line. i.e souocara.com)')?>
				</span></td>
			</tr>
			<tr class="myDomainTableRow">
				<td class="myDomainTableLabel"><?php  echo _e("Table Background Color:")?>
				</td>
				<td class="myDomainTableInput"><input class="color"
					value="<?php echo $themeBackgroundColor ?>"
					name="my_domain_list_bkg_theme_color"></td>
			</tr>
			<tr class="myDomainTableRow">
				<td class="myDomainTableLabel"><?php  echo _e("Table Font Color:")?>
				</td>
				<td class="myDomainTableInput"><input class="color"
					value="<?php echo $themeColor ?>" name="my_domain_list_theme_color">
				</td>
			</tr>
			<tr class="myDomainTableRow">
				<td class="myDomainTableLabel"><?php echo _e("Domain List Pagination: ") ?>
				</td>
				<td class="myDomainTableInput">

					<table name="my_domain_list_table_settings_pagination"
						class="options">
						<tr>
							<td><?php $paginationTypeChecked =($themePaginationType=='Letters')?' checked ':''; ?>
								<input type="radio" name="my_domain_list_pagination_type"
								value="Letters" <?php echo $paginationTypeChecked ?>> ABC</td>
							<td><?php $paginationTypeChecked =($themePaginationType=='Numbers')?' checked ':''; ?>
								<input type="radio" name="my_domain_list_pagination_type"
								value="Numbers" <?php echo $paginationTypeChecked ?>> 123 <select
								name="my_domain_list_page_numbers">
								<?php
								foreach($pageNumberArray as &$pageNumberValue){
									$pageNumberSelectOptionValue =($pageNumberValue==0)?'All':$pageNumberValue;
									$pageNumberSelectOptionSelected =($pageNumberValue==$themePages)?' selected ':'';
									?>
									<option value="<?php echo $pageNumberValue ?>"
									<?php  echo $pageNumberSelectOptionSelected ?>>
										<?php echo $pageNumberSelectOptionValue ?>
									</option>
									<?php
								}
								?>
							</select>
							</td>
						</tr>
						<tr>
							<td colspan="2"><span class="myDomainListLabelExtraSmall"> <?php  echo _e( 'Select type of pagination to use')?>
							</span></td>
						</tr>
					</table>
				</td>
			</tr>
			<tr class="myDomainTableRow">
				<td class="myDomainTableLabel"><?php echo _e("Domain List Filter: ") ?>
				</td>
				<td class="myDomainTableInput"><select name="my_domain_list_filter">
				<?php
				foreach($filterArray as $filterValue){
					$filterSelectOptionSelected =($filterValue==$themeFilter)?' selected ':'';
					?>
						<option value="<?php echo $filterValue ?>"
						<?php echo $filterSelectOptionSelected ?>>
							<?php echo $filterValue ?>
						</option>
						<?php
				}
				?>
				</select> <br> <span class="myDomainListLabelExtraSmall"> <?php  echo _e('Select item to allow filtering')?>
				</span></td>
			</tr>
		</table>
		<p>
			<input id="domainlistsubmit" class="button-primary" type="submit"
				name="my_domain_list_save_submit" value="Save Domain List Settings">
		</p>
	</form>
	<?php
	}

	/**
	 * This function uses ajax to display the Manage Domain Table
	 *
	 * @return null
	 */
	public function adminAjaxHandler() {
		$nounce = wp_create_nonce( 'my_domain_list_table_content' );
		$out =  '<script>
			function my_domain_list_table_paging(count)
			{
				jQuery.get('.ajaxurl.', 
				{action:"my-domain-list-table",count: count, _ajax_nonce: "'.$nounce.'"}, 
				function(str)	{
				 jQuery("#my_domain_list_table_content").html(str); 
				 jQuery("#my_domain_list_table_content").fadeIn("fast"); 
				 jQuery("#my_domain_list-page-loading").hide();
				});
			}	
            jQuery(document).ready(function(){
	            my_domain_list_table_paging( 1 );               
            });		 			
		</script>';
		$out .= '<span id="my_domain_list_table_content"></span>';

		echo $out; //has to be an echo here
	}



	/**
	 * This function displays domain list table with admin options
	 *
	 * @return null
	 */
	public function displayAdminTable() {
		//Verifies the AJAX request to prevent processing requests external of the blog.
		check_ajax_referer( "my_domain_list_table_content" );
		MyDomainListPlugin::getInstance()->disableBrowserCache();

		global $wpdb;
		$my_domain_list_table_name = $wpdb->prefix . "mydomainlist";
		$my_domain_list_offer_table_name = $wpdb->prefix . "mydomainlist_offer";

		/*SELECT A.name, owner, registrar, forsale, A.price, created,
		 CHANGED , expires, A.updated_at, count(B.price) as 'offer_count' FROM wp_mydomainlist AS A LEFT JOIN wp_mydomainlist_offer AS B ON A.name = B.name group by A.name order by A.name
		 */

		$whoIsData =  $wpdb->get_results("SELECT A.name, owner, registrar, forsale, A.price, created,
CHANGED , expires, A.updated_at, count(B.price) as 'offer_count' FROM " .$my_domain_list_table_name." AS A LEFT JOIN " .$my_domain_list_offer_table_name." AS B ON A.name = B.name group by A.name order by A.name",ARRAY_A);

		$settingsData = get_option('my_domain_list_settings');
		$domainListColumns = "registrar,owner,created,changed,expires,sale price,unpublish,del site,get info";
		$domainListCount = count($whoIsData);
		?>
	<div class="myDomainListLabelMessage">
		<span class="myDomainListLabelMessageText"></span><span
			class="myDomainListLabelStandardMessage">There are <?php  echo $domainListCount ?>
			domains in your account </span>
	</div>
	<?php
	$paginationItemsPerPage = (!is_null($settingsData['themePages']))? $settingsData['themePages']: 0;
	$paginationCurrentPage = ((int)$_REQUEST[ 'count' ]==0)? 1 : (int)$_REQUEST[ 'count' ];
	if($paginationItemsPerPage!=0){
		MyDomainListPlugin::getInstance()->showPagination($domainListCount, $paginationItemsPerPage, $paginationCurrentPage);
		$pageStart = ($paginationCurrentPage - 1) *$paginationItemsPerPage;
		$pageEnd =min($domainListCount,($pageStart+$paginationItemsPerPage));
	}else{
		$pageStart=0;
		$pageEnd= $domainListCount;
	}
	MyDomainListPlugin::getInstance()->showPageLoadingIndicator();
	?>
	<script>
            jQuery(document).ready(function(){
                jQuery(".myDomainListUpdateCount").click(
                    function() { 
                    	jQuery("#my_domain_list-page-loading").show();
                         my_domain_list_table_paging(this.id);
                    });
		jQuery(".myDomainListUnpublishAction").click(function(){
			if(jQuery(this).is(':checked')){ 			
				jQuery(".myDomainListLabelStandardMessage").hide();
				jQuery(".myDomainListLabelMessageText").show();
				jQuery(".myDomainListLabelMessageText").text("Unpublishing " + this.value + " will hide the domain's information from the user table.");
			}else{			 
				jQuery(".myDomainListLabelStandardMessage").show();
				jQuery(".myDomainListLabelMessageText").hide();
			}
		});
		jQuery(".myDomainListGetInfoAction").click(function(){
			if(jQuery(this).is(':checked')){ 			
				jQuery(".myDomainListLabelStandardMessage").hide();
				jQuery(".myDomainListLabelMessageText").show();
				jQuery(".myDomainListLabelMessageText").text("This action will collect " + this.value + " domain's information from whois API.");
			}else{			 
				jQuery(".myDomainListLabelStandardMessage").show();
				jQuery(".myDomainListLabelMessageText").hide();
			}
		});
		jQuery(".myDomainListDeleteAction").click(function(){
			if(jQuery(this).is(':checked')){ 			
				jQuery(".myDomainListLabelStandardMessage").hide();
				jQuery(".myDomainListLabelMessageText").show();
				jQuery(".myDomainListLabelMessageText").text('Deleting ' + this.value + ' will delete all domain related information including offers made.');
			}else{			 
				jQuery(".myDomainListLabelStandardMessage").show();
				jQuery(".myDomainListLabelMessageText").hide();
			}
		});
            });
        </script>
	<br>
	<table class="widefat">
		<thead>
			<tr>
				<th class="myDomainListTH">Name</th>
				<?php
				$domainListColumnArray = explode(",",$domainListColumns);
				foreach ($domainListColumnArray as &$domainListColumnValue)
				{
					?>
				<th class="myDomainListTH"><?php echo MyDomainListPlugin::getInstance()->properCase($domainListColumnValue) ?>
				</th>
				<?php
				}
				?>
			</tr>
		</thead>
		<tbody>
		<?php
		for($pos=$pageStart;$pos<$pageEnd;$pos++){
			$whoIsDataValue =$whoIsData[$pos];
			$whoIsDomainName =$whoIsDataValue['name'];
			if(!empty($whoIsDomainName)){
				$domainSalePrice =$whoIsDataValue['price'];
				$domainForSaleIsChecked = ($whoIsDataValue['forsale']=='Y')? 'checked': '';
				$whoIsDomainUpdatedAt = $whoIsDataValue['updated_at'];
				$whoIsDomainOfferCount = $whoIsDataValue['offer_count'];
				?>
			<tr class="myDomainListTR">
			<?php if ($whoIsDomainOfferCount >0) { ?>
				<td class="myDomainListTD"><?php echo trim($whoIsDomainName) ?>
					<div class="myDomainTableOfferCountBackground" title="# offers">
					<?php echo $whoIsDomainOfferCount ?>
					</div></td>
					<?php
			}else{
				?>
				<td class="myDomainListTD"><?php echo trim($whoIsDomainName) ?></td>
				<?php
			}

			for ( $i = 0; $i <= count($domainListColumnArray)-1; $i += 1) {
				switch($domainListColumnArray[$i]) {

					case "unpublish":
						?>
				<td class="myDomainListTD"><input
					class="myDomainListUnpublishAction" type="checkbox"
					name="myDomainListForSale[<?php echo $whoIsDomainName ?>]"
					value="<?php echo $whoIsDomainName?>"
					<?php echo $domainForSaleIsChecked ?> /></td>
					<?php
					break;
case "sale price":
	?>
				<td class="myDomainListTD">$<input type="input" size="5"
					name="myDomainListPrice[<?php echo $whoIsDomainName ?>]"
					value="<?php echo $domainSalePrice?>" /></td>
					<?php
					break;
case "get info":
	?>
				<td class="myDomainListTD"><input class="myDomainListGetInfoAction"
					type="checkbox"
					name="myDomainListUpdate[<?php echo $whoIsDomainName ?>]"
					value="<?php echo $whoIsDomainName?>" />&nbsp;&nbsp;<a href="#"
					class="myDomainListUpdateInfo"
					title="Domain was last updated on: <?php echo $whoIsDomainUpdatedAt?>">...</a>
				</td>
				<?php
				break;
case "del site":
	?>
				<td class="myDomainListTD"><input class="myDomainListDeleteAction"
					type="checkbox"
					name="myDomainListRemove[<?php echo $whoIsDomainName ?>]"
					value="<?php echo $whoIsDomainName?>" /></td>
					<?php
					break;
default:
	?>
				<td class="myDomainListTD"><?php echo $whoIsDataValue[''.$domainListColumnArray[$i].''] ?>
				</td>
				<?php
				break;
				}
			}
			?>
			</tr>
			<?php
			}
		}
		?>
		</tbody>
	</table>
	<?php
	die();
	}

	public function updateDomainInfo($myDomainListArray){
		global $wpdb;
		$my_domain_list_table_name = $wpdb->prefix . "mydomainlist";
		if(!empty($myDomainListArray)){
			foreach ($myDomainListArray as &$myDomainListArrayValue) {
				$myDomainListUrlParseArray = parse_url($myDomainListArrayValue);
				$myDomainListHostValue = $myDomainListUrlParseArray['path'];
				if ($myDomainListUrlParseArray['host']){
					$myDomainListHostValue = $myDomainListUrlParseArray['host'];
				}
				$myDomainListUpdateReturned = array();
				if(preg_match ("/^[a-z0-9][a-z0-9\-]+[a-z0-9](\.[a-z]{2,4})+$/i", $myDomainListHostValue)){ //validate domain
					$myDomainWhoIsFeed = file_get_contents('http://my-domain-list.com/api/index.php/whoisapi/domain/id/'.trim($myDomainListHostValue).'/format/json');
					if(($myDomainWhoIsFeed) && (!empty($myDomainWhoIsFeed['domain']))){
						$myDomainWhoIsFeedEncoded = json_decode($myDomainWhoIsFeed,true);
						$myDomainListWhoIsFeedReturnedName =$myDomainWhoIsFeedEncoded['domain']['regrinfo']['domain']['name'];
						if(!empty($myDomainListWhoIsFeedReturnedName)){
							$myDomainListWhoIsDomainCategoryArray =explode(".",$myDomainListWhoIsFeedReturnedName);
							$myDomainListWhoIsDomainCategoryValue = '.'.end($myDomainListWhoIsDomainCategoryArray);
							$rows_affected = $wpdb->query( $wpdb->prepare( "INSERT INTO ".$my_domain_list_table_name."( name, owner, registrar, extension, created, changed, expires, updated_at, price) VALUES ( %s, %s, %s, %s, %s,  %s, %s, %s, %d ) ON DUPLICATE KEY UPDATE price = price",
							$myDomainListWhoIsFeedReturnedName,
							$myDomainWhoIsFeedEncoded['domain']['regrinfo']['owner']['name'],
							$myDomainWhoIsFeedEncoded['domain']['regyinfo']['registrar'],
							$myDomainListWhoIsDomainCategoryValue,
							$myDomainWhoIsFeedEncoded['domain']['regrinfo']['domain']['created'],
							$myDomainWhoIsFeedEncoded['domain']['regrinfo']['domain']['changed'],
							$myDomainWhoIsFeedEncoded['domain']['regrinfo']['domain']['expires'],
							date("Y/m/d"), 0
							));  //end query
						}
					}
				}else{ 
					array_push($myDomainListUpdateReturned,$myDomainListHostValue);
				}
			}
		}
		return $myDomainListUpdateReturned;
	}

}
?>