<?php

/**
 * User facing class
 *
 * @author Luciana Bruscino
 * @license GPL
 */

class UserFacing
{
	/**
	 * This function handles the wordpress shortcode for the user facing table. This creates a "[my-domain-list-portfolio]" shortcode that supports two attributes: ["size" and "show"]
	 * It also handles ajax calls for pagination.
	 *
	 * @return user facing table from ajax call
	 */
	function shortcodeHandler($atts){
		$settingsData = get_option('my_domain_list_settings');
		extract( shortcode_atts( array(
                'show' => 'all',
                'size' => 'large',
		), $atts ) );
		$settingsData['themeTableSize']= "{$size}";
		$settingsData['themeTableShow']= "{$show}";
		update_option( 'my_domain_list_settings',$settingsData );
		$nounce = wp_create_nonce( 'my_domain_list_user_table_content' );
		$nounceDialog = wp_create_nonce( 'my_domain_list_make_offer_content' );


		$settingsData = get_option('my_domain_list_settings');
		$themeBackgroundColorColor = (!is_null($settingsData['themeBackgroundColor']))? $settingsData['themeBackgroundColor']: '000';
		$themeColorColor = (!is_null($settingsData['themeColor']))? $settingsData['themeColor']: 'fff';
		$themeTableSizeClass = (!is_null($settingsData['themeTableSize']))? 'myDomainListTable'.$settingsData['themeTableSize']: 'myDomainListTablesmall';
		$themeTableShow = (!is_null($settingsData['themeTableShow']))? $settingsData['themeTableShow']: 'all';
		$themeFilter = (!is_null($settingsData['themeTableFilter']))? $settingsData['themeTableFilter']: 'None';
		$themePaginationType = (!is_null($settingsData['themePaginationType']))? $settingsData['themePaginationType']: 'Numbers';
		$themePages = (!is_null($settingsData['themePages']))? $settingsData['themePages']: 0;
		if($themeTableShow == 'all'){
			$domainListColumns ="owner,extension,registrar,created,changed,expires,price,offer";
		}else{
			$domainListColumns=preg_replace('/\s+/', '',$themeTableShow); //strip whitespaces
		}
		$out =  '<script>
				 function my_domain_list_make_offer(attrs)
			    {	       				
                    jQuery.get("'.get_option('siteurl').'/wp-admin/admin-ajax.php", 
				    {action:"my-domain-list-make-offer",attr: attrs, _ajax_nonce: "'.$nounceDialog.'"},function(str)	{
				    	jQuery("#my_domain_list_make_offer_content").html(str); 
				    	jQuery("#my_domain_list_make_offer_content").fadeIn("fast"); //animation
				     	jQuery("#my_domain_list-page-loading").hide(); 
				    });
}
			    function my_domain_list_table_paging(count, filter)
			    {	    		    	      				
					var pluginData = { "themeColor": "'.$themeColorColor.'", 
						"themeBackgroundColor": "'.$themeBackgroundColorColor.'",
						"themeSize": "'.$themeTableSizeClass.'", 
						"themeFilter":"'.$themeFilter.'",
						"themePagination" : "'.$themePaginationType.'",
						"themeColumns":"'.$domainListColumns.'",
						"themePages":"'.$themePages.'"
					};
			    	jQuery.get("'.get_option('siteurl').'/wp-admin/admin-ajax.php", 
				    {action:"my-domain-list-user-table",count: count,filter:filter, pluginData: pluginData, _ajax_nonce: "'.$nounce.'"}, function(str)	{    
jQuery("#my_domain_list_user_table_content").html(str);
jQuery("#my_domain_list_user_table_content").fadeIn("fast"); //animation
jQuery("#my_domain_list-page-loading").hide();
});
}
jQuery(document).ready(function(){
	          	  my_domain_list_table_paging( 1 ,"" );       
           		 });
			    </script>';
		$out .= '<div id="my_domain_list_user_table_content"></div>';
		return $out; //has to be a return here
	}


	/**
	 * This function processes the domain offer information into the database.
	 *
	 * @return message to user with information (name and price) about the offer.
	 */
	function processMakeOfferDialog(){
		//Verifies the AJAX request to prevent processing requests external of the blog.
		check_ajax_referer( "my_domain_list_make_offer_content" );
		$myDomainListOfferData = $_REQUEST[ 'attr' ];
		$myDomainListNameValue = $myDomainListOfferData[name];
		$myDomainListPriceValue = $myDomainListOfferData[price];
		$myDomainListEmailValue = $myDomainListOfferData[email];
		$myDomainListCommentsValue = $myDomainListOfferData[comments];
		$myDomainListCurrencyValue = $myDomainListOfferData[currency];
		global $wpdb;
		$my_domain_list_offer_table_name = $wpdb->prefix . "mydomainlist_offer";
		$query =  $wpdb->prepare( "INSERT INTO ".$my_domain_list_offer_table_name."( name, email, comments, price, currency, updated_at) VALUES ( %s, %s, %s, %f, %s, %s )",
		$myDomainListNameValue,
		$myDomainListEmailValue,
		$myDomainListCommentsValue,
		$myDomainListPriceValue,
		$myDomainListCurrencyValue,
		date("Y/m/d")
		);  //end query

		if ($wpdb->query($query) === FALSE) {
			$return =  new WP_Error('offer_insert_error', __('There has been a problem, please contact the website admin directly to make an offer.'));
		}
		if ( is_wp_error($return) ) {
			echo $return->get_error_message();
		}else{
			echo "Your offer of $" .$myDomainListPriceValue ." for ". $myDomainListNameValue . " has been submitted.";
		}
		die();
	}

	/**
	 * This function displays the filtering dropdown.
	 *@param string $themeFilter	The type of filtering i.e extension, owner, registrar
	 * @param string $themeFilterValue	The filter value picked by user i.e .com, .tel if themeFilter is extension
	 * @return void
	 */
	function showCategoryFilter($themeFilter, $themeFilterValue ){
		global $wpdb;
		$my_domain_list_table_name = $wpdb->prefix . "mydomainlist";
		if($themeFilter!='None'){
			$query = $wpdb->prepare("SELECT DISTINCT ".strtolower($themeFilter)." FROM ".$my_domain_list_table_name. " WHERE forsale !='Y'");
			$filteringDataArray =  $wpdb->get_results($query,ARRAY_N);
			if($filteringDataArray){
				?>

<span><?php echo $themeFilter ?>:</span>
<select id="my-domain-list-select-filter">
	<option class="updateFilter" value="">All</option>
	<?php

	foreach ( $filteringDataArray as $filteringDataValue){
		$filteringDataValueSelected = ($filteringDataValue[0] == $themeFilterValue)?'selected':'';
		?>
	<option <?php echo $filteringDataValueSelected ?> class="updateFilter"
		value="<?php echo $filteringDataValue[0] ?>">
		<?php echo $filteringDataValue[0] ?>
	</option>
	<?php
	}
	?>
</select>
<br class="myDomainListClear">
	<?php
			}
		}
	}

	/**
	 * This function displays the domain list from information saved in the database.
	 *
	 * @return null
	 */
	function displayUserTable() {
		//Verifies the AJAX request to prevent processing requests external of the blog.
		check_ajax_referer( "my_domain_list_user_table_content" );
		MyDomainListPlugin::getInstance()->disableBrowserCache();

		global $wpdb;
		$my_domain_list_table_name = $wpdb->prefix . "mydomainlist";

		$myDomainListPluginData = $_REQUEST[ 'pluginData' ];
		$domainListColumns = $myDomainListPluginData['themeColumns'];
		$themeColor =$myDomainListPluginData['themeColor'];
		$themeBackgroundColor =$myDomainListPluginData['themeBackgroundColor'];
		$themeFilter =$myDomainListPluginData['themeFilter'];
		$themeTableSizeClass=$myDomainListPluginData['themeSize'];
		$themePaginationType = $myDomainListPluginData['themePagination'];
		$themeFilterValue = $_REQUEST[ 'filter' ];
			
		UserFacing::showCategoryFilter($themeFilter, $themeFilterValue );
			
		if($themePaginationType =="Letters"){

			$query = $wpdb->prepare("SELECT DISTINCT (UCASE( LEFT( name, 1 ) ) ) as 'letters' FROM  ".$my_domain_list_table_name . " WHERE forsale !='Y'");
			if($themeFilterValue!=''){
				$query .= $wpdb->prepare(" AND " .strtolower($themeFilter). "= %s", $themeFilterValue);
			}
			$query .= " ORDER by name";
			$myDomainListAvailableLettersResults =  $wpdb->get_results($query, ARRAY_N);
			$myDomainListAvailableLetters = array();
			foreach($myDomainListAvailableLettersResults as $result ){
				$myDomainListAvailableLetters[] = $result[0]{0};
			}
			/*$paginationCurrentPage=((int)$_REQUEST[ 'count' ]==1)? $myDomainListAvailableLetters[0]:$_REQUEST[ 'count' ];	*/
			$paginationCurrentPage=((int)$_REQUEST[ 'count' ]==1)? 'All':$_REQUEST[ 'count' ];

			if($paginationCurrentPage=='All' || $_REQUEST[ 'count' ]=='All'){
				$query =$wpdb->prepare("SELECT name, owner, registrar, extension, forsale, expires, price, created, changed FROM ".$my_domain_list_table_name." WHERE forsale !='Y' ");
			}else{

				$query =$wpdb->prepare("SELECT name, owner, registrar, extension, forsale, expires, price, created, changed FROM ".$my_domain_list_table_name." WHERE forsale !='Y' AND UCASE( LEFT( name, 1 ) ) = '%s' ", $paginationCurrentPage);
			}
			if($themeFilterValue!=''){
				$query .= $wpdb->prepare(" AND ".strtolower($themeFilter). "= %s", $themeFilterValue);
			}
			$query .= " ORDER by name";
			$whoIsData =  $wpdb->get_results($query,ARRAY_A);
			$domainListCount = count($whoIsData);
			MyDomainListPlugin::getInstance()->showLetterPagination($myDomainListAvailableLetters,$paginationCurrentPage);
			$paginationItemsPerPage = 0;
			$pageStart=0;
			$pageEnd= $domainListCount;
		}else{
			$query =$wpdb->prepare("SELECT name, owner, registrar, extension, forsale, expires, price, created, changed FROM ".$my_domain_list_table_name. " WHERE forsale !='Y'");
			if($themeFilterValue!=''){
				$query .= $wpdb->prepare("  AND ".strtolower($themeFilter). "= %s", $themeFilterValue);
			}
			$query .= " ORDER by name";
			$whoIsData =  $wpdb->get_results($query,ARRAY_A);
			$domainListCount = count($whoIsData);
			$paginationItemsPerPage = $myDomainListPluginData['themePages'];
			$paginationCurrentPage = ((int)$_REQUEST[ 'count' ]==0)? 1 : (int)$_REQUEST[ 'count' ];
			MyDomainListPlugin::getInstance()->showPagination($domainListCount, $paginationItemsPerPage, $paginationCurrentPage);
			if($paginationItemsPerPage!=0){
				$pageStart = ($paginationCurrentPage - 1) *$paginationItemsPerPage;
				$pageEnd =min($domainListCount,($pageStart+$paginationItemsPerPage));
			}else{
				$pageStart=0;
				$pageEnd= $domainListCount;
			}
		}

		UserFacing::loadTemplate(WP_PLUGIN_DIR.'/my-domain-list/my-domain-list-make-offer-dialog.php');
		MyDomainListPlugin::getInstance()->showPageLoadingIndicator();
		?>

<br class="myDomainListClear">
<span
	id="my_domain_list_make_offer_content"></span>
<span class="myDomainListUserOfferMessages"><?php echo $myDomainListOfferMessage ?>
</span>
<script type="text/javascript">
	jQuery(document).ready(function(){
	
   	jQuery(".myDomainListUpdateCount").click(
		function() { 
        	jQuery("#my_domain_list-page-loading").show(); 
            	my_domain_list_table_paging( this.id ,jQuery("#my-domain-list-select-filter").val());
        });
   	jQuery("#my-domain-list-select-filter").change(
   	   function() { 
    	  	jQuery("#my_domain_list-page-loading").show(); 
		my_domain_list_table_paging( 1, this.value );
     	 })
 	});
</script>
<table class="<?php echo $themeTableSizeClass ?>">
	<thead>
		<tr style="background-color: #<?php echo $themeBackgroundColor ?>; color:#<?php echo $themeColor ?>">
			<th class="myDomainListTH">Name</th>
			<?php
			$domainListColumnArray = explode(",",$domainListColumns);
			foreach ($domainListColumnArray as &$domainListColumnValue)
			{
				?>
			<th class="myDomainListTH"><?php echo MyDomainListPlugin::getInstance()->properCase($domainListColumnValue) ?>
			</th>
			<?php } ?>
		</tr>
	</thead>
	<tbody>
	<?php
	for($pos=$pageStart;$pos<$pageEnd;$pos++){
		$whoIsDataValue =$whoIsData[$pos];
		$whoIsDomainName =$whoIsDataValue['name'];
		if(!empty($whoIsDomainName)){
			$domainSalePrice =$whoIsDataValue['price'];

			?>
		<tr class="myDomainListTR">
			<td class="myDomainListTD"><a
				href="http://<?php echo trim($whoIsDomainName) ?>" target="_blank"><?php echo trim($whoIsDomainName) ?>
			</a></td>
			<?php
			for ( $i = 0; $i <= count($domainListColumnArray)-1; $i += 1) {
				switch($domainListColumnArray[$i]) {
					case "offer":
						?>
			<td class="myDomainListTD"><input type="button" value="Make Offer"
				name="<?php echo $domainSalePrice .'|'. $whoIsDomainName ?>"
				class="myDomainListMakeOfferButton" /></td>
				<?php
				break;

case "price":
	?>
			<td class="myDomainListTD"><?php echo '$'.money_format('%i',$domainSalePrice)?><span
				class="offer" /></td>
				<?php
				break;
default:
	?>
			<td class="myDomainListTD"><?php echo $whoIsDataValue[''.$domainListColumnArray[$i].''] ?>
			</td>
			<?php
			break;
				}
			}
			?>
		</tr>
		<?php
		}
	}
	?>
	</tbody>
</table>
	<?php
	die();
	}

	 
	/**
	 * Parse a template file
	 *
	 * @param string $file	The template file you want to use
	 * @param array $data	Data that you want to use in the template
	 * @return void
	 */
	public function loadTemplate($file, $data=array()){

		// Make variables
		extract( $data );

		// Check if template exists
		if( file_exists($file) ){
			ob_start();
			include($file);
			$parsed = ob_get_contents();
			ob_end_clean();
			echo $parsed;
		} else {
			echo "Template doesn't exist.";
		}
	}
}
?>
