<?php
/*
 Plugin Name: My Domain List
 Plugin URI: http://my-domain-list.com
 Description: The My Domain List Plugin for WordPress allows domain owners to manage and promote their inventory of domains for sale.
 Author: Chad Edwards, Luciana Bruscino
 Version: 1.40
 Author URI: http://my-domain-list.com
 Copyright 2011 Chad_Edwards_Luciana_Bruscino (email : luciana123_2002@yahoo.com)
 */
if (!class_exists('MyDomainListPlugin', false)) {
	class MyDomainListPlugin {
		/**
		 * (Singleton) Instance of MyDomainListPlugin object
		 *
		 * @var MyDomainListPlugin
		 */
		private static $_instance = null;

		/**
		 * Retuns MyDomainListPlugin instance.
		 *
		 *
		 * @return MyDomainListPlugin
		 */
		public static function getInstance()
		{
			if(self::$_instance === null) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * This function initializes MyDomainListPlugin plugin
		 *
		 * @return null
		 */
		public static function initialize()
		{
			register_activation_hook( __FILE__, array( "MyDomainListPlugin", 'activate' ));
			register_uninstall_hook(__FILE__,  array( "MyDomainListPlugin", 'uninstall' ));
			register_deactivation_hook( __FILE__, array("MyDomainListPlugin", 'deactivate' ));
			add_action('init', array("MyDomainListPlugin", 'loadAssets'), 1);
			add_filter('plugin_action_links', array("MyDomainListPlugin", 'loadActionLinks'), 10, 2);
			if ( is_admin() ){
				require_once dirname( __FILE__ ) . '/my-domain-list-admin.php';
				require_once dirname( __FILE__ ) . '/my-domain-list-dashboard.php';
				add_action( 'admin_init', array("AdminFacing", "initializeScript") );
				add_action('admin_menu', array("AdminFacing", 'addAdminPage'));
				add_action('wp_ajax_my-domain-list-table',  array("AdminFacing", "displayAdminTable"));
				add_action('wp_ajax_nopriv_my-domain-list-table',  array("AdminFacing", "displayAdminTable"));
				add_action('wp_ajax_my-domain-list-dismiss-offer',  array("DashboardFacing", "dismissOffer"));
				add_action('wp_ajax_nopriv_my-domain-list-dismiss-offer',  array("DashboardFacing", "dismissOffer"));
				add_action('wp_dashboard_setup', array("MyDomainListPlugin","add_dashboard_widget") );
				wp_localize_script( 'my-domain-list-ajax-request', 'my_domain_ajax_script', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );
					
			}
			require_once dirname(__FILE__)."/my-domain-list-user-shortcode.php";
			add_action('wp_ajax_my-domain-list-user-table', array("UserFacing", "displayUserTable"));
			add_action('wp_ajax_nopriv_my-domain-list-user-table', array("UserFacing", "displayUserTable"));
			add_action('wp_ajax_nopriv_my-domain-list-make-offer', array("UserFacing", "processMakeOfferDialog"));
			add_action('wp_ajax_my-domain-list-make-offer', array("UserFacing", "processMakeOfferDialog"));

			add_shortcode( 'my-domain-list-portfolio',array("UserFacing", "shortcodeHandler"));
		}


		/**
		 * add_dashboard_widget
		 *
		 * This function creates the function used in the action hook for the dashboard widget
		 *
		 * return null
		 */
		function add_dashboard_widget() {
			wp_add_dashboard_widget('my_domain_list_dashboard_widget', 'My Domain List Offers', array("DashboardFacing","dashboard_widget_output"));
		}


		/**
		 * activate
		 *
		 * This function creates settings options (settings) entries in wp_options and mydomainlist table in mysql
		 *
		 * return null
		 */
		public function activate() {
			global $wpdb;
			$my_domain_list_table_name = $wpdb->prefix . "mydomainlist";
			$my_domain_list_offer_table_name = $wpdb->prefix . "mydomainlist_offer";
			$myDomainListSettingsData = array(
       		         'themeColor'=>'ffffff',
			 'themeBackgroundColor'=>'000000',
          	         'themePages'=>'',          	 
                     	 'themeTableSize'=>'small',
         	         'themeTableShow'=>'all',
                     	 'themeTableFilter'=>'None',
		     	 'themePaginationType' => 'Numbers'
		     	 );
		     	 add_option('my_domain_list_settings', $myDomainListSettingsData);
		     	 if($wpdb->get_var("SHOW TABLES LIKE '$my_domain_list_table_name'") != $my_domain_list_table_name) {
		     	 	$sql = "CREATE TABLE " . $my_domain_list_table_name . " (
	              name VARCHAR(200) NOT NULL,
	              owner VARCHAR(80) NOT NULL,
	              registrar VARCHAR(80) NOT NULL,     
	              extension tinytext NOT NULL,
	              forsale VARCHAR(1) DEFAULT 'N' NOT NULL,
	              price int(2) DEFAULT '0' NOT NULL,
	              created DATE NOT NULL,	      	      
	              changed DATE NOT NULL,	      	      
	              expires DATE NOT NULL,
	              created_at DATETIME NOT NULL,	      	      
	              updated_at DATETIME NOT NULL,	      
	              UNIQUE KEY (name)

	            );";
		     	 	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		     	 	dbDelta($sql);
		     	 }
		     	 if($wpdb->get_var("SHOW TABLES LIKE '$my_domain_list_offer_table_name'") != $my_domain_list_offer_table_name) {
		     	 	$sql = "CREATE TABLE " . $my_domain_list_offer_table_name . " (
	              id int(11) NOT NULL AUTO_INCREMENT,
		            name VARCHAR(200) NOT NULL,
                email VARCHAR(80) NOT NULL,
	              price int(2) NOT NULL,
	              comments TEXT,   	    
                currency VARCHAR(3),
	              updated_at DATETIME NOT NULL,	      
	              UNIQUE KEY (id)

	            );";
		     	 	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		     	 	dbDelta($sql);
		     	 }
		}

		/**
		 * deactivate
		 *
		 * This function cleans up the entries (settings) created in the wp_options table in mysql.
		 *
		 */
		public function deactivate() {
			delete_option('my_domain_list_settings');
		}

		/**
		 * uninstall
		 *
		 * This function drops the mydomainlist table in mysql. Domains will no longer be available
		 *
		 */
		public function uninstall(){
			global $wpdb;
			$mydomainlisttable = $wpdb->prefix."mydomainlist";
			$wpdb->query("DROP TABLE IF EXISTS $mydomainlisttable");

			$mydomainlistoffertable = $wpdb->prefix."mydomainlist_offer";
			$wpdb->query("DROP TABLE IF EXISTS $mydomainlistoffertable");
		}

		/**
		 * loadActionsLinks
		 *
		 * This function creates an Setting link in the Plugin Page.
		 *
		 * @param    string   $links
		 * @param    string   $file
		 * @return   string	  A link to the setting admin page
		 */
		public function loadActionLinks($links, $file) {
			$plugin_file = basename(__FILE__);
			if (basename($file) == $plugin_file) {
				$settings_link = '<a href="options-general.php?page=my-domain-list-options-page">'.__('Settings', 'MyDomainList').'</a>';
				array_unshift($links, $settings_link);
			}
			return $links;
		}

/**
		 * This function disables the browser from caching the data
		 *
		 * @return null
		 */
		public function disableBrowserCache() {
			header("Expires: Tue, 03 Jul 2001 06:00:00 GMT");
			header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
			header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
			header("Cache-Control: post-check=0, pre-check=0", false);
			header("Pragma: no-cache");
		}

		/**
		 * loadAssets
		 *
		 * This function loads the necessary javascript and css files needed to support the plugin.
		 *
		 */
		public function loadAssets() {
			wp_enqueue_script('jquery');
			wp_register_script( 'my-domain-list_0', plugins_url('/js/my-domain-list-js-script.js', __FILE__), array('jquery'));
			wp_enqueue_script('my-domain-list_0');
			wp_register_script('my-domain-list_1', "http://jqueryui.com/ui/jquery.ui.core.js");
			wp_enqueue_script('my-domain-list_1');
			wp_register_script('my-domain-list_2', "http://jqueryui.com/ui/jquery.ui.widget.js");
			wp_enqueue_script('my-domain-list_2');
			wp_register_script('my-domain-list_3', "http://jqueryui.com/ui/jquery.ui.resizable.js");
			wp_enqueue_script('my-domain-list_3');
			wp_register_script('my-domain-list_4', "http://jqueryui.com/ui/jquery.ui.mouse.js");
			wp_enqueue_script('my-domain-list_4');
			wp_register_script('my-domain-list_5', "http://jqueryui.com/ui/jquery.ui.draggable.js");
			wp_enqueue_script('my-domain-list_5');
			wp_register_script('my-domain-list_6', "http://jqueryui.com/ui/jquery.ui.position.js");
			wp_enqueue_script('my-domain-list_6');
			wp_register_script('my-domain-list_7', "http://jqueryui.com/external/jquery.bgiframe-2.1.2.js");
			wp_enqueue_script('my-domain-list_7');
			wp_register_script('my-domain-list_8', "http://jqueryui.com/ui/jquery.ui.dialog.js");
			wp_enqueue_script('my-domain-list_8');
			wp_register_script('my-domain-list_9', "http://jqueryui.com/ui/jquery.ui.button.js");
			wp_enqueue_script('my-domain-list_9');
			wp_register_script('my-domain-list_10', "http://jqueryui.com/ui/jquery.effects.core.js");
			wp_enqueue_script('my-domain-list_10');

			$css_url = WP_PLUGIN_URL.'/my-domain-list/css/my-domain-list_style.css';
			$css_file = WP_PLUGIN_DIR.'/my-domain-list/css/my-domain-list_style.css';
			$css_dialog_url = WP_PLUGIN_URL.'/my-domain-list/css/my-domain-list_dialog.css';
			$css_dialog_file = WP_PLUGIN_DIR.'/my-domain-list/css/my-domain-list_dialog.css';
			wp_register_style('my-domain-list_dialog_jquery_stylesheet', 'http://jqueryui.com/themes/base/jquery.ui.all.css');
			wp_enqueue_style('my-domain-list_dialog_jquery_stylesheet');

			if (file_exists($css_file)) {
				wp_register_style('my-domain-list_stylesheet', $css_url);
				wp_enqueue_style('my-domain-list_stylesheet');
			}
			if (file_exists($css_dialog_file)) {
					
				wp_register_style('my-domain-list_dialog_stylesheet', $css_dialog_url);
				wp_enqueue_style('my-domain-list_dialog_stylesheet');
			}

		}

		/**
		 * properCase
		 *
		 * This function converts a string into its proper case format.
		 *
		 * @param    string   $string    Any string value
		 * @return   string   String formatted in proper case
		 */
		public function properCase($string){
			$string = strtolower($string);
			return substr_replace($string, strtoupper(substr($string, 0, 1)), 0, 1);
		}

		

		/**
		 * This function displays page loading div on the page
		 *
		 * @return null
		 */
		public function showPageLoadingIndicator(){
			?>
				<div id="my_domain_list-page-loading" style="display: none">
				<img src="<?php echo  WP_PLUGIN_URL.'/my-domain-list/img/ajax-loader.gif' ?>" />
				</div>
			<?php
		}

		/**
		 * showLetterPagination
		 *
		 * This function displays pagination by letter.
		 *
		 * @param    array   $myDomainListAvailableLetters    Available letters in the domain list
		 * @param    int   $pageSelected    Current page letter selected
		 * @return   null
		 */
		public function showLetterPagination($myDomainListAvailableLetters, $pageSelected='A'){

			?>
<div class="myDomainPageMenu">
<?php
$myDomainListAllLetters =  array(All,A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z);
array_push($myDomainListAvailableLetters, "All");
foreach ($myDomainListAllLetters as &$value)
{
	if($pageSelected==$value){
		?>
	<span
		class="myDomainListUpdateCount myDomainListPaging myDomainListPagingActive"
		id="<?php echo $value ?>"><?php echo $value ?> </span>
		<?php
	}else if(in_array($value, $myDomainListAvailableLetters)){
		?>
	<span class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $value ?>"><?php echo $value ?> </span>
		<?php
	}
	else{
		?>
	<span class="myDomainListPaging myDomainListPagingDisabled"><?php echo $value ?>
	</span>
	<?php
	}

}//end for loop

?>
</div>
<div id="my_domain_list-page-loading" style="display: none">
	<img
		src="<?php echo  WP_PLUGIN_URL.'/my-domain-list/img/ajax-loader.gif' ?>" />
</div>
<?php
		}
		/**
		 * showPagination
		 *
		 * This function displays the appropriate page numbers.
		 *
		 * @param    int   $count    Total number of items
		 * @param    int   $itemsPerPage    Items per page the user wants to display
		 * @param    int   $pageSelected    Current page number selected
		 * @return   null
		 */
		public function showPagination($domainCount, $itemsPerPage, $pageSelected=1){

			if(!$adjacents) {
				$adjacents = 1;
			}

			if(!$itemsPerPage) {
				$itemsPerPage = $domainCount;
			}
			if($domainCount>0){
			$pages = ceil($domainCount/$itemsPerPage);
			$pageLimit = 7;
			$lpm1 = $pages - 1;



			if($pages > 1)
			{
				?>
<div class="myDomainPageMenu">
<?php
if ( $pageSelected > 1 ) {
	$previous = $pageSelected-1;
	?>
	<span class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $previous ?>">« previous</span>
		<?php
}  //end if previous
if ($pages < $pageLimit + ($adjacents * 2))	//not enough pages to bother breaking it up
{
	for ($i = 1; $i <= $pages; $i++)
	{
		if($pageSelected==$i){
			?>
	<span
		class="myDomainListUpdateCount myDomainListPaging myDomainListPagingActive"
		id="<?php echo $i ?>"><?php echo $i ?> </span>
		<?php
		}else{
			?>
	<span class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $i ?>"><?php echo $i ?> </span>
		<?php
		}
	}//end for loop
}elseif($pages >= $pageLimit + ($adjacents * 2))	//enough pages to hide some
{
	if($pageSelected < 1 + ($adjacents * 3))	//close to beginning; only hide later pages
	{
		for ($i = 1; $i < 4 + ($adjacents * 2); $i++)
		{
			if($pageSelected==$i){
				?>
	<span
		class="myDomainListUpdateCount myDomainListPaging myDomainListPagingActive"
		id="<?php echo $i ?>"><?php echo $i ?> </span>
		<?php
			}else{
				?>
	<span class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $i ?>"><?php echo $i ?> </span>
		<?php
			}
		}
		?>
	<span class='elipses myDomainListPaging'>...</span> <span
		class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $lpm1 ?>"><?php echo $lpm1 ?> </span> <span
		class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $pages ?>"><?php echo $pages ?> </span>
		<?php
	}//end if close to beginning; only hide later pages
	elseif($pages - ($adjacents * 2) > $page && $page > ($adjacents * 2)) //in middle; hide some front and some back
	{
		?>
	<span class="myDomainListUpdateCount myDomainListPaging" id="1">1</span>
	<span class="myDomainListUpdateCount myDomainListPaging" id="2">2</span>
	<span class='elipses myDomainListPaging'>...</span>
	<?php
	for ($i = $pageSelected - $adjacents; $i <= $pageSelected + $adjacents; $i++)
	{
		if($pageSelected==$i){
			?>
	<span
		class="myDomainListUpdateCount myDomainListPaging myDomainListPagingActive"
		id="<?php echo $i ?>"><?php echo $i ?> </span>
		<?php
		}else{
			?>
	<span class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $i ?>"><?php echo $i ?> </span>
		<?php
		}
	}
	?>
	<span class='elipses myDomainListPaging'>...</span>" <span
		class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $lpm1 ?>"><?php echo $lpm1 ?> </span> <span
		class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $pages ?>"><?php echo $pages ?> </span>
		<?php
	}//end if in middle; hide some front and some back
	else//close to end; only hide early pages
	{
		?>
	<span class="myDomainListUpdateCount myDomainListPaging" id="1">1</span>
	<span class="myDomainListUpdateCount myDomainListPaging" id="2">2</span>
	<span class='elipses myDomainListPaging'>...</span>
	<?php
	for ($i = $pages - (1 + ($adjacents * 3)); $i <= $pages; $i++)
	{
		if($pageSelected==$i){
			?>
	<span
		class="myDomainListUpdateCount myDomainListPaging myDomainListPagingActive"
		id="<?php echo $i ?>"><?php echo $i ?> </span>
		<?php
		}else{
			?>
	<span class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $i ?>"><?php echo $i ?> </span>
		<?php
		}
	}
	}//end close to end; only hide early pages
}//end if enough pages to hide some
if ( $pageSelected < $pages ) {
	$next = $pageSelected+1;
	?>
	<span class="myDomainListUpdateCount myDomainListPaging"
		id="<?php echo $next ?>">next »</span>
		<?php
}
?>
</div>
<div id="my_domain_list-page-loading" style="display: none">
	<img
		src="<?php echo  WP_PLUGIN_URL.'/my-domain-list/img/ajax-loader.gif' ?>" />
</div>
<?php
			}//end if pages > 1
		}
		}
	}//end class




}
$myDomainList = new MyDomainListPlugin;
$myDomainList->initialize();

?>